==> synhelper-8.x-1.51.tar.gz: synhelper/src/Service/ProductImport.php <==
<?php

namespace Drupal\synhelper\Service;

use Drupal\Core\Config\FileStorage;
use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\commerce_product\Entity\ProductAttributeValue;

/**
 * ProductImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class ProductImport implements ContentImportInterface {
  /**
   * Global directory variable.
   *
   * @var string
   */
  protected $directory;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\TaxonomyImport
   */

  protected $taxonomyImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\ParagraphImport
   */
  protected $paragraphImport;

  /**
   * Controller constructor.
   */
  public function __construct(
    ContentImportInterface $filesImport,
    ContentImportInterface $paragraphImport,
    ContentImportInterface $taxonomyImport
  ) {
    $this->filesImport = $filesImport;
    $this->paragraphImport = $paragraphImport;
    $this->taxonomyImport = $taxonomyImport;
  }

  /**
   * Import Products.
   */
  public function import(string $directory) {
    $this->$directory = $directory;
    $sourceProducts = new FileStorage($directory . '/products');
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      $this->updateCreateProduct($product_array);
    }
  }

  /**
   * Update or Create Products.
   */
  private function updateCreateProduct(array $product_array) {
    $created_product = $this->getProductFromBase($product_array['field_unique_name']);
    if (!($created_product)) {
      $this->createProduct($product_array, 'full_create');
    }
    elseif (!empty($product_array['related_products'])) {
      $created_product_id = $created_product->id();
      $this->setRelated($created_product_id, $product_array['related_products']);
    }
  }

  /**
   * Create product.
   */
  private function createProduct(array $product_array, string $statement = 'full_create') {
    if ($statement == 'full_create') {
      $created_product_id = $this->procedureOfProductCreation($product_array)->id();
      if (!empty($product_array['related_products'])) {
        $this->setRelated($created_product_id, $product_array['related_products']);
      }
    }
    elseif ($statement == 'only_as_related') {
      $created_product = $this->getProductFromBase($product_array['field_unique_name']);
      if ($created_product) {
        return $created_product->id();
      }
      $created_product_id = $this->procedureOfProductCreation($product_array)->id();
    }
    return $created_product_id;
  }

  /**
   * Procedure of creation.
   */
  private function procedureOfProductCreation(array $product_array) {
    if (!empty($product_array['variations'])) {
      $variations = $this->importVariations($product_array);
    }
    $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
    foreach ($product_array as $key => $value) {
      switch ($key) {
        case 'field_image':
        case 'field_gallery':
          $n[$key] = $this->filesImport->importImages($value);
          break;

        case 'field_attach':
          $n[$key] = $this->filesImport->importAttach($value);
          break;

        case 'field_catalog':
          $n[$key] = $this->taxonomyImport->importTaxonomyField($value);
          break;

        case 'field_tx_brand':
          $n[$key] = $this->taxonomyImport->importTaxonomyField($value);
          break;

        case 'field_tx_options':
          foreach ($value as $termName) {
            $terms[] = $this->taxonomyImport->importTaxonomyField($termName);
          }
          $n[$key] = $terms;
          break;

        case 'field_paragraph':
          $n[$key] = $this->paragraphImport->import($value);
          break;

        case 'variations':
          $n[$key] = $variations;
          break;

        case 'related_products':
          break;

        default:
          $n[$key] = $value;
          break;
      }
    }
    $n['uid'] = 1;
    $product = $storage->create($n);
    $product->save();
    return $product;
  }

  /**
   * Search for created product.
   */
  private function getProductFromBase(string $unique_name) {
    $products = \Drupal::entityTypeManager()->getStorage('commerce_product')->loadByProperties(['field_unique_name' => $unique_name]);
    $product = array_shift($products);
    return $product ?? NULL;
  }

  /**
   * Search for products_array in $this->directory/products.
   */
  private function getProductFromFile(string $unique_name) {
    $sourceProducts = new FileStorage($this->$directory . '/products');
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      if ($product_array['field_unique_name'] == $unique_name) {
        break;
      }
    }
    return $product_array;
  }

  /**
   * Create Related Products.
   */
  private function setRelated(string $created_product_id, array $related_products) {
    $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
    $products_ids = [];
    foreach ($related_products as $unique_name) {
      $product_array = $this->getProductFromFile($unique_name);
      if (!empty($product_array)) {
        $products_ids[] = $this->createProduct($product_array, 'only_as_related');
      }
    }
    $created_product = $storage->load($created_product_id);
    $created_product->set("field_rf_product", $products_ids);
    $created_product->save();
  }

  /**
   * Imports product variations.
   */
  private function importVariations(array $product) : array {
    foreach ($product['variations'] as $vid => $variation_content) {
      $v = [
        'uid' => 1,
        'id' => $vid,
        'title' => $product['title'],
        'type' => 'variation',
        'sku' => $vid,
        'price' => [
          'number' => (int) filter_var($variation_content['price'], FILTER_SANITIZE_NUMBER_INT),
          'currency_code' => $variation_content['currency'],
        ],
        'field_oldprice' => $variation_content['field_oldprice'],
        'field_image' => $this->filesImport->importImages($variation_content['field_image']),
        'field_gallery' => $this->filesImport->importImages($variation_content['field_gallery']),
      ];
      if (!empty($variation_content['attributes'])) {
        foreach ($variation_content['attributes'] as $key => $value) {
          $v["attribute_$key"] = $this->importAttribute($value, $key);
        }
      }
      $variation = ProductVariation::create($v);
      $variations[] = $variation;
      $variation->save();
    }
    return $variations;
  }

  /**
   * Import Attributes.
   */
  private function importAttribute(array $fields, string $name) {
    $ids = $this->issetAttribute($fields, $name);
    if (empty($ids)) {
      $a = [
        'attribute' => $name,
      ];
      foreach ($fields as $key => $value) {
        switch ($key) {
          case 'field_image':
          case 'field_gallery':
            $a[$key] = $this->filesImport->importImages($value);
            break;

          case 'field_hex':
            $a[$key] = strtoupper($value);
            break;

          case 'field_attach':
            $a[$key] = $this->filesImport->importAttach($value);
            break;

          case 'field_paragraph':
            $a[$key] = $this->paragraphImport->import($value);
            break;

          default:
            $a[$key] = $value;
            break;
        }
      }
      $attribute = ProductAttributeValue::create($a);
      $attribute->save();
      return $attribute;
    }
    else {
      return ProductAttributeValue::load(array_shift($ids));
    }
  }

  /**
   * Check already created attributes.
   */
  private function issetAttribute(array $fields, string $name) {
    $query = \Drupal::entityQuery('commerce_product_attribute_value');
    if ($name == 'color') {
      $query->condition('field_hex', $fields['field_hex']);
    }
    else {
      $query->condition('name', $fields['name']);
    }
    return $query->execute();
  }

}

==> synhelper-8.x-1.56.tar.gz: synhelper/src/Service/ProductImport.php <==
<?php

namespace Drupal\synhelper\Service;

use Drupal\Core\Config\FileStorage;
use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\commerce_product\Entity\ProductAttributeValue;

/**
 * ProductImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class ProductImport implements ContentImportInterface {
  /**
   * Global directory variable.
   *
   * @var string
   */
  protected $directory;

  /**
   * Global logger variable.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $logger;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\TaxonomyImport
   */

  protected $taxonomyImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\ParagraphImport
   */
  protected $paragraphImport;

  /**
   * Controller constructor.
   */
  public function __construct(
    ContentImportInterface $filesImport,
    ContentImportInterface $paragraphImport,
    ContentImportInterface $taxonomyImport
  ) {
    $this->filesImport = $filesImport;
    $this->paragraphImport = $paragraphImport;
    $this->taxonomyImport = $taxonomyImport;
  }

  /**
   * {@inheritdoc}
   */
  public function setLogger($logger) {
    $this->logger = $logger;
  }

  /**
   * Import Products.
   */
  public function import(string $directory) {
    $this->directory = $directory;
    $sourceProducts = new FileStorage($directory . '/products');
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      $this->updateCreateProduct($product_array);
    }
  }

  /**
   * Update or Create Products.
   */
  private function updateCreateProduct(array $product_array) {
    $created_product = $this->getProductFromBase($product_array['field_unique_name']);
    if (!($created_product)) {
      $this->createProduct($product_array, 'full_create');
    }
    elseif (!empty($product_array['related_products'])) {
      $created_product_id = $created_product->id();
      $this->setRelated($created_product_id, $product_array['related_products']);
    }
  }

  /**
   * Create product.
   */
  private function createProduct(array $product_array, string $statement = 'full_create') {
    if ($statement == 'full_create') {
      $created_product_id = $this->procedureOfProductCreation($product_array)->id();
      if (!empty($product_array['related_products'])) {
        $this->setRelated($created_product_id, $product_array['related_products']);
      }
    }
    elseif ($statement == 'only_as_related') {
      $created_product = $this->getProductFromBase($product_array['field_unique_name']);
      if ($created_product) {
        return $created_product->id();
      }
      $created_product_id = $this->procedureOfProductCreation($product_array)->id();
    }
    return $created_product_id;
  }

  /**
   * Procedure of creation.
   */
  private function procedureOfProductCreation(array $product_array) {
    if (!empty($product_array['variations'])) {
      $variations = $this->importVariations($product_array);
    }
    $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
    foreach ($product_array as $key => $value) {
      switch ($key) {
        case 'field_image':
        case 'field_gallery':
          $n[$key] = $this->filesImport->importImages($value);
          break;

        case 'field_attach':
          $n[$key] = $this->filesImport->importAttach($value);
          break;

        case 'field_catalog':
          $n[$key] = $this->taxonomyImport->importTaxonomyField($value);
          break;

        case 'field_tx_brand':
          $n[$key] = $this->taxonomyImport->importTaxonomyField($value);
          break;

        case 'field_tx_options':
          foreach ($value as $termName) {
            $terms[] = $this->taxonomyImport->importTaxonomyField($termName);
          }
          $n[$key] = $terms;
          break;

        case 'field_paragraph':
          $n[$key] = $this->paragraphImport->import($value);
          break;

        case 'variations':
          $n[$key] = $variations;
          break;

        case 'related_products':
          break;

        default:
          $n[$key] = $value;
          break;
      }
    }
    $n['uid'] = 1;
    $product = $storage->create($n);
    $product->save();
    $this->logger->notice('...');
    return $product;
  }

  /**
   * Search for created product.
   */
  private function getProductFromBase(string $unique_name) {
    $products = \Drupal::entityTypeManager()->getStorage('commerce_product')->loadByProperties(['field_unique_name' => $unique_name]);
    $product = array_shift($products);
    return $product ?? NULL;
  }

  /**
   * Search for products_array in $this->directory/products.
   */
  private function getProductFromFile(string $unique_name) {
    $sourceProducts = new FileStorage($this->directory . '/products');
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      if ($product_array['field_unique_name'] == $unique_name) {
        break;
      }
    }
    return $product_array;
  }

  /**
   * Create Related Products.
   */
  private function setRelated(string $created_product_id, array $related_products) {
    $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
    $products_ids = [];
    foreach ($related_products as $unique_name) {
      $product_array = $this->getProductFromFile($unique_name);
      if (!empty($product_array)) {
        $products_ids[] = $this->createProduct($product_array, 'only_as_related');
      }
    }
    $created_product = $storage->load($created_product_id);
    $created_product->set("field_rf_product", $products_ids);
    $created_product->save();
  }

  /**
   * Imports product variations.
   */
  private function importVariations(array $product) : array {
    foreach ($product['variations'] as $vid => $variation_content) {
      $v = [
        'uid' => 1,
        'id' => $vid,
        'title' => $product['title'],
        'type' => 'variation',
        'sku' => $vid,
        'price' => [
          'number' => (int) filter_var($variation_content['price'], FILTER_SANITIZE_NUMBER_INT),
          'currency_code' => $variation_content['currency'],
        ],
        'field_oldprice' => $variation_content['field_oldprice'],
        'field_image' => $this->filesImport->importImages($variation_content['field_image']),
        'field_gallery' => $this->filesImport->importImages($variation_content['field_gallery']),
      ];
      if (!empty($variation_content['attributes'])) {
        foreach ($variation_content['attributes'] as $key => $value) {
          $v["attribute_$key"] = $this->importAttribute($value, $key);
        }
      }
      $variation = ProductVariation::create($v);
      $variations[] = $variation;
      $variation->save();
    }
    return $variations;
  }

  /**
   * Import Attributes.
   */
  private function importAttribute(array $fields, string $name) {
    $ids = $this->issetAttribute($fields, $name);
    if (empty($ids)) {
      $a = [
        'attribute' => $name,
      ];
      foreach ($fields as $key => $value) {
        switch ($key) {
          case 'field_image':
          case 'field_gallery':
            $a[$key] = $this->filesImport->importImages($value);
            break;

          case 'field_hex':
            $a[$key] = strtoupper($value);
            break;

          case 'field_attach':
            $a[$key] = $this->filesImport->importAttach($value);
            break;

          case 'field_paragraph':
            $a[$key] = $this->paragraphImport->import($value);
            break;

          default:
            $a[$key] = $value;
            break;
        }
      }
      $attribute = ProductAttributeValue::create($a);
      $attribute->save();
      return $attribute;
    }
    else {
      return ProductAttributeValue::load(array_shift($ids));
    }
  }

  /**
   * Check already created attributes.
   */
  private function issetAttribute(array $fields, string $name) {
    $query = \Drupal::entityQuery('commerce_product_attribute_value');
    if ($name == 'color') {
      $query->condition('field_hex', $fields['field_hex']);
    }
    else {
      $query->condition('name', $fields['name']);
    }
    return $query->execute();
  }

}
